using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace DesignerExample
{
	public partial class Form1 : Form
	{
		private string rootFolder = "";

		public Form1()
		{
			InitializeComponent();
		}

		private void GatherList(string rootFolder)
		{
			listBoxPreview.Items.Clear();
			GatherListItems(rootFolder);
		}

		private void GatherListItems(string rootFolder)
		{
			foreach (string folderName in Directory.GetDirectories(rootFolder))
			{
				GatherListItems(folderName);
			}
			foreach (string fileName in Directory.GetFiles(rootFolder, "*.mp3"))
			{
				listBoxPreview.Items.Add(fileName);
			}
		}

		private void buttonRootFolderBrowse_Click(object sender, EventArgs e)
		{
			FolderBrowserDialog fbd = new FolderBrowserDialog();
			fbd.SelectedPath = rootFolder;
			fbd.ShowNewFolderButton = false;

			if (fbd.ShowDialog() == DialogResult.OK)
			{
				textBoxRootFolder.Text = rootFolder = fbd.SelectedPath;
				buttonGo.Enabled = true;
				buttonSave.Enabled = false;
				labelStatus.Visible = false;
				listBoxPreview.Items.Clear();
			}
			labelErrorMessage.Visible = false;
		}

		private void buttonGo_Click(object sender, EventArgs e)
		{
			try
			{
				labelErrorMessage.Visible = false;
				labelStatus.Text = "Searching...";
				this.Refresh();
				GatherList(rootFolder);
				labelStatus.Text = String.Format("{0} MP3 files found", listBoxPreview.Items.Count);
				labelStatus.Visible = true;
				if (listBoxPreview.Items.Count > 0)
				{
					buttonSave.Enabled = true;
				}
			}
			catch (DirectoryNotFoundException ex)
			{
				labelErrorMessage.Visible = true;
				labelErrorMessage.Text = ex.Message;
			}
			catch (Exception ex)
			{
				labelErrorMessage.Visible = true;
				labelErrorMessage.Text = "Unknown error: " + ex.Message;
			}
		}

		private void buttonSave_Click(object sender, EventArgs e)
		{
			if (listBoxPreview.Items.Count > 0)
			{
				SaveFileDialog sfd = new SaveFileDialog();
				sfd.DefaultExt = "m3u";
				sfd.Filter = "Playlist files (*.m3u)|*.m3u";
				sfd.OverwritePrompt = true;
				sfd.InitialDirectory = rootFolder;

				if (sfd.ShowDialog() == DialogResult.OK)
				{
					try
					{
						StreamWriter stream = new StreamWriter(sfd.OpenFile());
						foreach (string s in listBoxPreview.Items)
						{
							stream.WriteLine(s);
						}
						stream.Close();
						labelStatus.Text = "File saved";
					}
					catch (Exception ex)
					{
						labelErrorMessage.Visible = true;
						labelErrorMessage.Text = "Error saving file: " + ex.Message;
					}
				}
			}
		}
	}
}
