using System;
using System.Collections.Generic;
using System.Text;

namespace OperatorOverloading
{
	class Point
	{
		public float x, y, z;

		public Point()
		{
			x = y = z = 0.0f;
		}

		public Point(float x, float y, float z)
		{
			this.x = x;
			this.y = y;
			this.z = z;
		}

		public Point(Point other)
		{
			this.x = other.x;
			this.y = other.y;
			this.z = other.z;
		}

		public float Length
		{
			get
			{
				return System.Convert.ToSingle(Math.Sqrt(x * x + y * y + z * z));
			}
		}

		public static float operator ^(Point p0, Point p1)
		{
			Point t = p0 - p1;
			return t.Length;
		}

		public static Point operator +(Point p0, Point p1)
		{
			Point r = new Point();
			r.x = p0.x + p1.x;
			r.y = p0.y + p1.y;
			r.z = p0.z + p1.z;
			return r;
		}

		public static Point operator -(Point p0, Point p1)
		{
			Point r = new Point();
			r.x = p0.x - p1.x;
			r.y = p0.y - p1.y;
			r.z = p0.z - p1.z;
			return r;
		}

		public float this[int index]
		{
			get
			{
				switch (index)
				{
					case 0:
						return x;

					case 1:
						return y;

					case 2:
						return z;

					default:
						throw new ArgumentException();
				}
			}
			set
			{
				switch (index)
				{
					case 0:
						x = value;
						break;

					case 1:
						y = value;
						break;

					case 2:
						z = value;
						break;

					default:
						throw new ArgumentException();
				}
			}
		}

		public override string ToString()
		{
			return String.Format("[{0}, {1}, {2}]", x, y, z);
		}
	}

	class Program
	{
		static void Main(string[] args)
		{
			Point p0 = new Point();
			Point p1 = new Point(-10.0f, 10.0f, 0.0f);

			p1[2] = 10.0f;
			p0 = p0 + p1;
			Console.WriteLine("Length of p0 is: {0}", p0.Length);
			Console.WriteLine("Distance from p0 to p1 is: {0}", p0 ^ p1);
			Console.WriteLine("p0 is: {0}", p0);
			Console.ReadLine();
		}
	}
}
